<?php
/**
 *
 * @package PhpBB Xmas extension
 * @copyright (c) 2016 Stoker
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace stoker\xmas\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{
	/** @var \phpbb\config\config */
	protected $config;

	/** @var \phpbb\template\template */
	protected $template;

	/**
	* Constructor
	*
	* @param \phpbb\config\config        $config             Config object
	* @param \phpbb\template\template    $template           Template object
	* @return \stoker\xmas\event\listener
	* @access public
	*/
	public function __construct(\phpbb\config\config $config, \phpbb\template\template $template)
	{
		$this->config = $config;
		$this->template = $template;
	}

	/**
	* Assign functions defined in this class to event listeners in the core
	*
	* @return array
	* @static
	* @access public
	*/
	static public function getSubscribedEvents()
	{
		return array(
			'core.user_setup'					=> 'load_language_on_setup',
			'core.page_header'					=> 'get_xmas_config',
		);
	}
	
	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'stoker/xmas',
			'lang_set' => 'common',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	/**
	* Get config var
	*
	* @return null
	* @access public
	*/
	public function get_xmas_config()
	{
		$this->template->assign_var('ENABLE_XMAS', $this->config['enable_xmas']);
		$this->template->assign_var('ENABLE_XMAS_STORM', $this->config['enable_xmas_storm']);
		
		$this->template->assign_var('XMAS_STORM_MINSIZE', $this->config['xmas_storm_minsize']);
		$this->template->assign_var('XMAS_STORM_MAXSIZE', $this->config['xmas_storm_maxsize']);
		$this->template->assign_var('XMAS_STORM_FLAKECOUNT', $this->config['xmas_storm_flakecount']);
		
		$this->template->assign_var('XMAS_TESTMODE', $this->config['xmas_testmode']);
		$this->template->assign_var('XMAS_COUNTDOWN_ENABLE', $this->config['xmas_countdown_enable']);
		$this->template->assign_var('XMAS_COUNTDOWN_TESTMODE', $this->config['xmas_countdown_testmode']);
		$this->template->assign_var('XMAS_COUNTDOWN_DIRECTION', $this->config['xmas_countdown_direction']);
		$this->template->assign_var('XMAS_COUNTDOWN_DATE', $this->config['xmas_countdown_date']);
		$this->template->assign_var('XMAS_COUNTDOWN_OFFSET_ENABLE', $this->config['xmas_countdown_offset_enable']);
		$this->template->assign_var('XMAS_COUNTDOWN_LEADING_ENABLE', $this->config['xmas_countdown_leading_enable']);
		$this->template->assign_var('XMAS_COUNTDOWN_YANDM_ENABLE', $this->config['xmas_countdown_yandm_enable']);
		$this->template->assign_var('XMAS_COUNTDOWN_OFFSET', $this->config['xmas_countdown_offset']);
		$this->template->assign_var('XMAS_COUNTDOWN_YEAR', $this->config['xmas_countdown_year']);
		$this->template->assign_var('XMAS_COUNTDOWN_MONTH', $this->config['xmas_countdown_month']);
		$this->template->assign_var('XMAS_COUNTDOWN_TEXT', html_entity_decode($this->config['xmas_countdown_text']));
		$this->template->assign_var('XMAS_COUNTDOWN_TEXT_AFTER', html_entity_decode($this->config['xmas_countdown_text_after']));
		$this->template->assign_var('XMAS_COUNTDOWN_COMPLETE', html_entity_decode($this->config['xmas_countdown_complete']));
	}
}
